[Libreoffice-commits] core.git: jurt/com odk/CustomTarget_javadoc.mk ridljar/com ridljar/Jar_ridl.mk

2020-02-10 Thread Samuel Mehrbrodt (via logerrit)
 odk/CustomTarget_javadoc.mk   |2 
 ridljar/Jar_ridl.mk   |  108 +-
 ridljar/com/sun/star/comp/connections/Acceptor.java   |1 
 ridljar/com/sun/star/lib/connections/pipe/PipeConnection.java |2 
 4 files changed, 58 insertions(+), 55 deletions(-)

New commits:
commit 57eee86bab2efd63b7eec9d73a86b1cc0422de29
Author: Samuel Mehrbrodt 
AuthorDate: Wed Feb 5 12:19:06 2020 +0100
Commit: Samuel Mehrbrodt 
CommitDate: Mon Feb 10 09:46:43 2020 +0100

Cleanup: Move files to ridljar

These files are now part of ridl.jar instead of jurt.jar,
so move them accordingly.

Follow-up cleanup for ae855bf48163ff64d94cfc34aff8e37abdb5518d

Change-Id: I01df60d99f5296b6252b260f52160c3e62f4b8dc
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/88007
Tested-by: Jenkins
Reviewed-by: Samuel Mehrbrodt 

diff --git a/odk/CustomTarget_javadoc.mk b/odk/CustomTarget_javadoc.mk
index 9bc62e0887d2..f4562f092d50 100644
--- a/odk/CustomTarget_javadoc.mk
+++ b/odk/CustomTarget_javadoc.mk
@@ -13,7 +13,7 @@ odk_JAVAPACKAGES := com.sun.star.comp.helper \
com.sun.star.lib.uno.helper \
com.sun.star.lib.unoloader \
com.sun.star.uno \
-   $(SRCDIR)/jurt/com/sun/star/lib/util/UrlToFileMapper.java
+   $(SRCDIR)/ridljar/com/sun/star/lib/util/UrlToFileMapper.java
 
 $(eval $(call gb_CustomTarget_register_targets,odk/docs/java/ref,\
javadoc_log.txt \
diff --git a/ridljar/Jar_ridl.mk b/ridljar/Jar_ridl.mk
index 9cb3bbd2aaa3..6fc4688f0eab 100644
--- a/ridljar/Jar_ridl.mk
+++ b/ridljar/Jar_ridl.mk
@@ -33,6 +33,51 @@ $(eval $(call gb_Jar_add_packagedirs,ridl,\
 ))
 
 $(eval $(call gb_Jar_add_sourcefiles,ridl,\
+ridljar/com/sun/star/comp/bridgefactory/BridgeFactory \
+ridljar/com/sun/star/comp/connections/Acceptor \
+ridljar/com/sun/star/comp/connections/Connector \
+ridljar/com/sun/star/comp/connections/ConstantInstanceProvider \
+ridljar/com/sun/star/comp/connections/Implementation \
+ridljar/com/sun/star/comp/connections/PipedConnection \
+ridljar/com/sun/star/comp/loader/FactoryHelper \
+ridljar/com/sun/star/comp/loader/JavaLoader \
+ridljar/com/sun/star/comp/loader/JavaLoaderFactory \
+ridljar/com/sun/star/comp/loader/RegistrationClassFinder \
+ridljar/com/sun/star/comp/servicemanager/ServiceManager \
+ridljar/com/sun/star/comp/urlresolver/UrlResolver \
+ridljar/com/sun/star/lib/connections/pipe/PipeConnection \
+ridljar/com/sun/star/lib/connections/pipe/pipeAcceptor \
+ridljar/com/sun/star/lib/connections/pipe/pipeConnector \
+ridljar/com/sun/star/lib/connections/socket/ConnectionDescriptor \
+ridljar/com/sun/star/lib/connections/socket/SocketConnection \
+ridljar/com/sun/star/lib/connections/socket/socketAcceptor \
+ridljar/com/sun/star/lib/connections/socket/socketConnector \
+ridljar/com/sun/star/lib/uno/Proxy \
+ridljar/com/sun/star/lib/uno/bridges/java_remote/BridgedObject \
+ridljar/com/sun/star/lib/uno/bridges/java_remote/ProxyFactory \
+ridljar/com/sun/star/lib/uno/bridges/java_remote/RequestHandler \
+
ridljar/com/sun/star/lib/uno/bridges/java_remote/XConnectionInputStream_Adapter 
\
+
ridljar/com/sun/star/lib/uno/bridges/java_remote/XConnectionOutputStream_Adapter
 \
+ridljar/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge \
+ridljar/com/sun/star/lib/uno/environments/java/java_environment \
+ridljar/com/sun/star/lib/uno/environments/remote/IProtocol \
+ridljar/com/sun/star/lib/uno/environments/remote/IReceiver \
+ridljar/com/sun/star/lib/uno/environments/remote/IThreadPool \
+ridljar/com/sun/star/lib/uno/environments/remote/JavaThreadPool \
+ridljar/com/sun/star/lib/uno/environments/remote/JavaThreadPoolFactory \
+ridljar/com/sun/star/lib/uno/environments/remote/Job \
+ridljar/com/sun/star/lib/uno/environments/remote/JobQueue \
+ridljar/com/sun/star/lib/uno/environments/remote/Message \
+ridljar/com/sun/star/lib/uno/environments/remote/NativeThreadPool \
+ridljar/com/sun/star/lib/uno/environments/remote/ThreadId \
+ridljar/com/sun/star/lib/uno/environments/remote/ThreadPoolManager \
+ridljar/com/sun/star/lib/uno/environments/remote/remote_environment \
+ridljar/com/sun/star/lib/uno/protocols/urp/Cache \
+ridljar/com/sun/star/lib/uno/protocols/urp/Marshal \
+ridljar/com/sun/star/lib/uno/protocols/urp/PendingRequests \
+ridljar/com/sun/star/lib/uno/protocols/urp/Unmarshal \
+ridljar/com/sun/star/lib/uno/protocols/urp/UrpMessage \
+ridljar/com/sun/star/lib/uno/protocols/urp/urp \
 ridljar/com/sun/star/lib/uno/typedesc/FieldDescription \
 ridljar/com/sun/star/lib/uno/typedesc/MemberDescriptionHelper \
 ridljar/com/sun/star/lib/uno/typedesc/MethodDescription \
@@ -43,71 +88,26 @@ $(eval $(call gb_Jar_add_sourcefiles,ridl,\
 ridljar/com/sun/star/lib/uno/

[Libreoffice-commits] core.git: jurt/com

2019-11-17 Thread Caolán McNamara (via logerrit)
 jurt/com/sun/star/lib/connections/socket/socketConnector.java |4 
 1 file changed, 4 insertions(+)

New commits:
commit 28da9177229a1d8b6d4a3ba3d84dea2166caae8d
Author: Caolán McNamara 
AuthorDate: Sun Nov 17 13:48:59 2019 +
Commit: Caolán McNamara 
CommitDate: Sun Nov 17 18:12:41 2019 +0100

cid#1448367 Explicit null dereferenced

Change-Id: I1762ad30ba03ee1d06f85023a42646131a7ccde9
Reviewed-on: https://gerrit.libreoffice.org/83018
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/jurt/com/sun/star/lib/connections/socket/socketConnector.java 
b/jurt/com/sun/star/lib/connections/socket/socketConnector.java
index 68fdf00c1149..484ffd135e92 100644
--- a/jurt/com/sun/star/lib/connections/socket/socketConnector.java
+++ b/jurt/com/sun/star/lib/connections/socket/socketConnector.java
@@ -143,6 +143,10 @@ public final class socketConnector implements XConnector {
 throw new NoConnectException(e);
 }
 }
+
+if (socket == null)
+throw new ConnectionSetupException("no socket");
+
 XConnection con;
 try {
 // we enable tcpNoDelay for loopback connections because
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

[Libreoffice-commits] core.git: jurt/com jvmfwk/inc lingucomponent/source offapi/com sw/source

2019-08-03 Thread Andrea Gelmini (via logerrit)
 jurt/com/sun/star/comp/servicemanager/ServiceManager.java |2 +-
 jvmfwk/inc/elements.hxx   |2 +-
 lingucomponent/source/spellcheck/spell/sspellimp.cxx  |2 +-
 offapi/com/sun/star/report/ForceNewPage.idl   |2 +-
 sw/source/core/layout/ftnfrm.cxx  |2 +-
 sw/source/filter/ww8/ww8scan.cxx  |2 +-
 6 files changed, 6 insertions(+), 6 deletions(-)

New commits:
commit 87f5719d60027d6415e9406ced161f9cd8026f45
Author: Andrea Gelmini 
AuthorDate: Sun Aug 4 01:16:23 2019 +0200
Commit: Andrea Gelmini 
CommitDate: Sun Aug 4 07:49:31 2019 +0200

Fix typo

Change-Id: I2991d07cb777ee83c24931798035fcc17ae48662
Reviewed-on: https://gerrit.libreoffice.org/76908
Tested-by: Jenkins
Reviewed-by: Andrea Gelmini 

diff --git a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java 
b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
index fd1978018ec7..574983f1e238 100644
--- a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
+++ b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
@@ -585,7 +585,7 @@ public class ServiceManager implements XMultiServiceFactory,
  * The ServiceEnumerationImpl class provides an
  * implementation of the @see com.sun.star.container.XEnumeration 
interface.
  *
- * It is a inner wrapper for a java.util.Enumeration object.
+ * It is an inner wrapper for a java.util.Enumeration object.
  *
  * @see com.sun.star.lang.XSingleServiceFactory
  * @see com.sun.star.lang.XServiceInfo
diff --git a/jvmfwk/inc/elements.hxx b/jvmfwk/inc/elements.hxx
index 2bdaf4a7033a..4ec2e5c2fb28 100644
--- a/jvmfwk/inc/elements.hxx
+++ b/jvmfwk/inc/elements.hxx
@@ -90,7 +90,7 @@ public:
 
 /** reads the node /java/javaInfo.
 If javaInfo@xsi:nil = true then member bNil is set to true
-an no further elements are read.
+and no further elements are read.
  */
 void loadFromNode(xmlDoc * pDoc,xmlNode * pJavaInfo);
 /** The attribute nil will be set to false. The function gets the value
diff --git a/lingucomponent/source/spellcheck/spell/sspellimp.cxx 
b/lingucomponent/source/spellcheck/spell/sspellimp.cxx
index 43f6bef717a0..3bbf8cc66f36 100644
--- a/lingucomponent/source/spellcheck/spell/sspellimp.cxx
+++ b/lingucomponent/source/spellcheck/spell/sspellimp.cxx
@@ -139,7 +139,7 @@ Sequence< Locale > SAL_CALL SpellChecker::getLocales()
 
 // to prefer dictionaries with configuration entries we will only
 // use those old style dictionaries that add a language that
-// is not yet supported by the list od new style dictionaries
+// is not yet supported by the list of new style dictionaries
 MergeNewStyleDicsAndOldStyleDics( aDics, aOldStyleDics );
 
 if (!aDics.empty())
diff --git a/offapi/com/sun/star/report/ForceNewPage.idl 
b/offapi/com/sun/star/report/ForceNewPage.idl
index 8cc0b03c12c9..76dd0e4a963e 100644
--- a/offapi/com/sun/star/report/ForceNewPage.idl
+++ b/offapi/com/sun/star/report/ForceNewPage.idl
@@ -24,7 +24,7 @@
  module com {  module sun {  module star {  module report {
 
 
-/** Specifies if the section will be printed on an separate page.
+/** Specifies if the section will be printed on a separate page.
 This does not apply to page header or page footer.
 @see XSection
  */
diff --git a/sw/source/core/layout/ftnfrm.cxx b/sw/source/core/layout/ftnfrm.cxx
index 89f52716e4f0..9826cf7f9e08 100644
--- a/sw/source/core/layout/ftnfrm.cxx
+++ b/sw/source/core/layout/ftnfrm.cxx
@@ -2757,7 +2757,7 @@ bool SwContentFrame::MoveFootnoteCntFwd( bool bMakePage, 
SwFootnoteBossFrame *pO
 // then move the content inside of it.
 // If it is a container or the reference differs, create a new 
footnote and add
 // it into the container.
-// Create also a SectionFrame if currently in a area inside a footnote.
+// Create also a SectionFrame if currently in an area inside a 
footnote.
 SwFootnoteFrame* pTmpFootnote = pNewUpper->IsFootnoteFrame() ? 
static_cast(pNewUpper) : nullptr;
 if( !pTmpFootnote )
 {
diff --git a/sw/source/filter/ww8/ww8scan.cxx b/sw/source/filter/ww8/ww8scan.cxx
index 3e2e802b1abf..e74a6907bec1 100644
--- a/sw/source/filter/ww8/ww8scan.cxx
+++ b/sw/source/filter/ww8/ww8scan.cxx
@@ -7058,7 +7058,7 @@ static void lcl_checkFontname( OUString& sString )
 // for efficiency, we'd like to use String methods as far as possible.
 // Hence, we will:
 // 1) convert all invalid chars to \u0001
-// 2) then erase all \u0001 chars (if anywere found), and
+// 2) then erase all \u0001 chars (if anywhere found), and
 // 3) erase leading/trailing ';', in case a font name was
 //completely removed
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https

[Libreoffice-commits] core.git: jurt/com

2019-05-15 Thread Andrea Gelmini (via logerrit)
 jurt/com/sun/star/uno/AnyConverter.java |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 42b012e4dcb3ccb7e0aeb82515734499dc4ce2ed
Author: Andrea Gelmini 
AuthorDate: Wed May 15 09:07:08 2019 +
Commit: Julien Nabet 
CommitDate: Thu May 16 08:00:12 2019 +0200

Fix typo

Change-Id: I6f7a40e8fefe09f9799927853b66dcae6c7a31d1
Reviewed-on: https://gerrit.libreoffice.org/72388
Reviewed-by: Julien Nabet 
Tested-by: Julien Nabet 

diff --git a/jurt/com/sun/star/uno/AnyConverter.java 
b/jurt/com/sun/star/uno/AnyConverter.java
index 857c842fcc5b..a54e7c3a8efe 100644
--- a/jurt/com/sun/star/uno/AnyConverter.java
+++ b/jurt/com/sun/star/uno/AnyConverter.java
@@ -215,7 +215,7 @@ public class AnyConverter
 }
 
 /**
- * Converts an Char object or an Any object containing a Char object into a
+ * Converts a Char object or an Any object containing a Char object into a
  * simple char.
  *
  * @param object the object to convert.
@@ -231,7 +231,7 @@ public class AnyConverter
 }
 
 /**
- * Converts an Boolean object or an Any object containing a Boolean object
+ * Converts a Boolean object or an Any object containing a Boolean object
  * into a simple boolean.
  *
  * @param object the object to convert.
@@ -247,7 +247,7 @@ public class AnyConverter
 }
 
 /**
- * Converts an Byte object or an Any object containing a Byte object into a
+ * Converts a Byte object or an Any object containing a Byte object into a
  * simple byte.
  *
  * @param object the object to convert.
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

[Libreoffice-commits] core.git: jurt/com

2019-02-17 Thread Libreoffice Gerrit user
 jurt/com/sun/star/lib/util/AsynchronousFinalizer.java |4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

New commits:
commit ea3c25358e3136cf900bc4e7d1bd6387dcca7883
Author: Samuel Mehrbrodt 
AuthorDate: Fri Feb 15 11:31:04 2019 +0100
Commit: Samuel Mehrbrodt 
CommitDate: Mon Feb 18 08:04:28 2019 +0100

tdf#123481 jurt: Avoid thread deadlocking

Change-Id: I7b6454090aeb1046a814520166a5b8c39b716f6d
Reviewed-on: https://gerrit.libreoffice.org/67861
Tested-by: Jenkins
Reviewed-by: Noel Grandin 
Reviewed-by: Samuel Mehrbrodt 

diff --git a/jurt/com/sun/star/lib/util/AsynchronousFinalizer.java 
b/jurt/com/sun/star/lib/util/AsynchronousFinalizer.java
index 0e7ecc41ba4d..588b8fe388f6 100644
--- a/jurt/com/sun/star/lib/util/AsynchronousFinalizer.java
+++ b/jurt/com/sun/star/lib/util/AsynchronousFinalizer.java
@@ -92,7 +92,9 @@ public final class AsynchronousFinalizer {
 done = true;
 queue.notify();
 }
-thread.join();
+// tdf#123481 Only join if we are not in our own thread, else we have 
a deadlock
+if (Thread.currentThread() != thread)
+thread.join();
 }
 
 /**
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

[Libreoffice-commits] core.git: jurt/com ridljar/com ridljar/Jar_ridl.mk ridljar/test

2016-06-07 Thread Noel Grandin
 jurt/com/sun/star/lib/uno/environments/remote/Job.java   |3 
 jurt/com/sun/star/lib/uno/environments/remote/Message.java   |   16 
 jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java |   22 -
 jurt/com/sun/star/lib/uno/protocols/urp/PendingRequests.java |9 
 jurt/com/sun/star/lib/uno/protocols/urp/Unmarshal.java   |   13 
 jurt/com/sun/star/lib/uno/protocols/urp/UrpMessage.java  |6 
 jurt/com/sun/star/lib/uno/protocols/urp/urp.java |   44 --
 ridljar/Jar_ridl.mk  |4 
 ridljar/com/sun/star/lib/uno/typedesc/FieldDescription.java  |   23 -
 ridljar/com/sun/star/lib/uno/typedesc/MemberDescriptionHelper.java   |9 
 ridljar/com/sun/star/lib/uno/typedesc/MethodDescription.java |   53 +-
 ridljar/com/sun/star/lib/uno/typedesc/TypeDescription.java   |  215 
+++---
 ridljar/com/sun/star/uno/IFieldDescription.java  |   46 --
 ridljar/com/sun/star/uno/IMemberDescription.java |   61 --
 ridljar/com/sun/star/uno/IMethodDescription.java |   73 ---
 ridljar/com/sun/star/uno/ITypeDescription.java   |  174 

 ridljar/com/sun/star/uno/Type.java   |   21 
 ridljar/com/sun/star/uno/UnoRuntime.java |4 
 ridljar/test/com/sun/star/lib/uno/typedesc/TypeDescription_Test.java |   59 +-
 19 files changed, 323 insertions(+), 532 deletions(-)

New commits:
commit 970b0ebb67d4033d70795e586a26c7a695c14194
Author: Noel Grandin 
Date:   Mon Jun 6 14:21:20 2016 +0200

[API CHANGE] Drop deprecated  I*Description interfaces

And make the fields of com.sun.star.uno.Type private

Change-Id: Ied7698b4157460e9726f271092c92b6b382239fd
Reviewed-on: https://gerrit.libreoffice.org/25971
Reviewed-by: Stephan Bergmann 
Tested-by: Stephan Bergmann 

diff --git a/jurt/com/sun/star/lib/uno/environments/remote/Job.java 
b/jurt/com/sun/star/lib/uno/environments/remote/Job.java
index f65..8ec4492 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/Job.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/Job.java
@@ -27,7 +27,6 @@ import java.lang.reflect.InvocationTargetException;
 
 import com.sun.star.lib.uno.typedesc.MethodDescription;
 import com.sun.star.uno.Any;
-import com.sun.star.uno.IMethodDescription;
 import com.sun.star.uno.Type;
 import com.sun.star.uno.UnoRuntime;
 import com.sun.star.uno.XCurrentContext;
@@ -79,7 +78,7 @@ public class Job {
 if (_iMessage.isRequest()) {
 Object result = null;
 Throwable exception = null;
-IMethodDescription md = _iMessage.getMethod();
+MethodDescription md = _iMessage.getMethod();
 Object[] args = _iMessage.getArguments();
 XCurrentContext oldCC = UnoRuntime.getCurrentContext();
 UnoRuntime.setCurrentContext(_iMessage.getCurrentContext());
diff --git a/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java 
b/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
index 7b96414..0ab2a29 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
@@ -89,7 +89,7 @@ public class JobQueue {
 try {
   enter(2000, _disposeId);
 } catch(Throwable throwable) {
-synchronized (this) {
+synchronized (JobQueue.this) {
 if(!jobList.isEmpty() || _active) { // there was a job in 
progress, so give a stack
 System.err.println(getClass().getName() + " - 
exception occurred:" + throwable);
 throwable.printStackTrace(System.err);
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2016-06-06 Thread Stephan Bergmann
 jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java |8 +---
 1 file changed, 5 insertions(+), 3 deletions(-)

New commits:
commit 5c2f970557791aa2b4a65a1c1298492a0f313225
Author: Stephan Bergmann 
Date:   Mon Jun 6 10:49:11 2016 +0200

cid#1362511: Concurrent data access violation

Change-Id: I35a381f9601178a3aab98b11172d33372d5c3dc1

diff --git a/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java 
b/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
index 131f2b5..7b96414 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
@@ -89,9 +89,11 @@ public class JobQueue {
 try {
   enter(2000, _disposeId);
 } catch(Throwable throwable) {
-if(!jobList.isEmpty() || _active) { // there was a job in 
progress, so give a stack
-System.err.println(getClass().getName() + " - exception 
occurred:" + throwable);
-throwable.printStackTrace(System.err);
+synchronized (this) {
+if(!jobList.isEmpty() || _active) { // there was a job in 
progress, so give a stack
+System.err.println(getClass().getName() + " - 
exception occurred:" + throwable);
+throwable.printStackTrace(System.err);
+}
 }
 }
 finally {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2016-06-03 Thread Noel Grandin
 jurt/com/sun/star/lib/uno/environments/remote/ThreadId.java |   13 
 1 file changed, 5 insertions(+), 8 deletions(-)

New commits:
commit 0d1ce0a79e1ab1193d741df52ededf5933d93115
Author: Noel Grandin 
Date:   Thu Jun 2 15:29:00 2016 +0200

Use AtomicLong in ThreadId instead of synchronizing

Change-Id: Ia10bab23b0cecb587cd3faa9c7e93b18384ecb88
Reviewed-on: https://gerrit.libreoffice.org/25827
Tested-by: Jenkins 
Reviewed-by: Noel Grandin 

diff --git a/jurt/com/sun/star/lib/uno/environments/remote/ThreadId.java 
b/jurt/com/sun/star/lib/uno/environments/remote/ThreadId.java
index 535d727..f8dacc7 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/ThreadId.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/ThreadId.java
@@ -19,18 +19,15 @@
 
 package com.sun.star.lib.uno.environments.remote;
 
-import com.sun.star.uno.UnoRuntime;
 import java.io.UnsupportedEncodingException;
-import java.math.BigInteger;
 import java.util.Arrays;
+import java.util.concurrent.atomic.AtomicLong;
+
+import com.sun.star.uno.UnoRuntime;
 
 public final class ThreadId {
 public static ThreadId createFresh() {
-BigInteger c;
-synchronized (PREFIX) {
-c = count;
-count = count.add(BigInteger.ONE);
-}
+long c = count.getAndIncrement();
 try {
 return new ThreadId((PREFIX + c).getBytes("UTF-8"));
 } catch (UnsupportedEncodingException e) {
@@ -103,7 +100,7 @@ public final class ThreadId {
 }
 
 private static final String PREFIX = "java:" + UnoRuntime.getUniqueKey() + 
":";
-private static BigInteger count = BigInteger.ZERO;
+private static final AtomicLong count = new AtomicLong(0);
 
 private final byte[] id;
 private int hash = 0;
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2016-06-02 Thread Noel Grandin
 jurt/com/sun/star/lib/uno/environments/remote/Job.java  |2 
 jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java |   58 
 2 files changed, 24 insertions(+), 36 deletions(-)

New commits:
commit 3e4fad756a451eca546eb4b2cf481172c523c71a
Author: Noel Grandin 
Date:   Wed Jun 1 15:15:02 2016 +0200

Use ArrayList for JobQueue

and make various internals of the class privatey

(This is not an ABI change, as package
com.sun.star.lib.uno.environments.remote is not considered part of the
stable URE interface; it is not included in the documentation at
.)

Change-Id: I25719239c0208b770ecd96b452b4220ac02b309d
Reviewed-on: https://gerrit.libreoffice.org/25779
Reviewed-by: Stephan Bergmann 
Tested-by: Stephan Bergmann 

diff --git a/jurt/com/sun/star/lib/uno/environments/remote/Job.java 
b/jurt/com/sun/star/lib/uno/environments/remote/Job.java
index 9dc2052..f65 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/Job.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/Job.java
@@ -41,8 +41,6 @@ import com.sun.star.uno.XCurrentContext;
  * @since   UDK1.0
  */
 public class Job {
-protected Job _next;
-
 protected IReceiver _iReceiver;
 protected Message  _iMessage;
   Object_disposeId;
diff --git a/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java 
b/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
index a4dc753..131f2b5 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
@@ -19,6 +19,8 @@
 
 package com.sun.star.lib.uno.environments.remote;
 
+import java.util.ArrayList;
+
 import com.sun.star.lang.DisposedException;
 
 /**
@@ -27,7 +29,7 @@ import com.sun.star.lang.DisposedException;
  * For every jobs thread id exists a job queue which is registered
  * at the ThreadPool.
  *
- * A JobQueue is splitted in a sync job queue and an async job queue.
+ * A JobQueue is split into a sync job queue and an async job queue.
  * The sync job queue is the registered queue, it delegates async jobs
  * (put by putjob) into the async queue, which is only
  * known by the sync queue.
@@ -43,25 +45,24 @@ public class JobQueue {
  */
 private static final boolean DEBUG = false;
 
-protected Job _head; // the head of the job list
-protected Job _tail; // the tail of the job list
+final ArrayList jobList = new ArrayList();
 
-protected ThreadId  _threadId;   // the thread id of the queue
-protected int   _ref_count = 0;  // the stack deepness
-protected boolean   _createThread;   // create a worker thread, if needed
-protected boolean   _createThread_now;   // create a worker thread, if 
needed
-protected Thread_worker_thread;  // the thread that does the jobs
+private ThreadId  _threadId;   // the thread id of the queue
+protected int _ref_count = 0;  // the stack deepness
+private boolean   _createThread;   // create a worker thread, if needed
+private boolean   _createThread_now;   // create a worker thread, if needed
+private Thread_worker_thread;  // the thread that does the jobs
 
-protected Object_disposeId; // the active dispose id
-protected Object_doDispose = null;
-protected Throwable _throwable;
+private Object_disposeId; // the active dispose id
+private Object_doDispose = null;
+private Throwable _throwable;
 
-protected JobQueue  _async_jobQueue; // chaining job queues for asyncs
+JobQueue  _async_jobQueue; // chaining job queues for asyncs
 protected JobQueue  _sync_jobQueue;  // chaining job queues for syncs
 
-protected boolean _active = false;
+private boolean _active = false;
 
-protected JavaThreadPoolFactory _javaThreadPoolFactory;
+private JavaThreadPoolFactory _javaThreadPoolFactory;
 
 /**
  * A thread for dispatching jobs.
@@ -88,7 +89,7 @@ public class JobQueue {
 try {
   enter(2000, _disposeId);
 } catch(Throwable throwable) {
-if(_head != null || _active) { // there was a job in progress, 
so give a stack
+if(!jobList.isEmpty() || _active) { // there was a job in 
progress, so give a stack
 System.err.println(getClass().getName() + " - exception 
occurred:" + throwable);
 throwable.printStackTrace(System.err);
 }
@@ -186,13 +187,13 @@ public class JobQueue {
  * @return a job or null if timed out.
  */
 private Job removeJob(int waitTime) {
-if(DEBUG) System.err.println("# " + getClass().getName() + 
".removeJob:" + _head + " " + _threadId);
+if(DEBUG) System.err.println("# " + getClass().getName() + 
".removeJob:" + jobList + " " + _threadId);
 
 Job job = null;
 

[Libreoffice-commits] core.git: jurt/com jurt/test jurt/workbench

2016-05-05 Thread Miklos Vajna
 jurt/com/sun/star/comp/bridgefactory/BridgeFactory.java
|2 ++
 jurt/com/sun/star/comp/connections/Acceptor.java   
|3 +++
 jurt/com/sun/star/comp/connections/Connector.java  
|3 +++
 jurt/com/sun/star/comp/connections/ConstantInstanceProvider.java   
|2 ++
 jurt/com/sun/star/comp/connections/Implementation.java 
|3 +++
 jurt/com/sun/star/comp/connections/PipedConnection.java
|2 ++
 jurt/com/sun/star/comp/loader/FactoryHelper.java   
|2 ++
 jurt/com/sun/star/comp/loader/JavaLoader.java  
|2 ++
 jurt/com/sun/star/comp/loader/JavaLoaderFactory.java   
|2 ++
 jurt/com/sun/star/comp/loader/RegistrationClassFinder.java 
|3 +++
 jurt/com/sun/star/comp/servicemanager/ServiceManager.java  
|3 +++
 jurt/com/sun/star/comp/urlresolver/UrlResolver.java
|3 +++
 jurt/com/sun/star/lib/connections/pipe/PipeConnection.java 
|3 +++
 jurt/com/sun/star/lib/connections/pipe/pipeAcceptor.java   
|3 +++
 jurt/com/sun/star/lib/connections/pipe/pipeConnector.java  
|3 +++
 jurt/com/sun/star/lib/connections/socket/ConnectionDescriptor.java 
|3 +++
 jurt/com/sun/star/lib/connections/socket/SocketConnection.java 
|2 ++
 jurt/com/sun/star/lib/connections/socket/socketAcceptor.java   
|3 +++
 jurt/com/sun/star/lib/connections/socket/socketConnector.java  
|3 +++
 jurt/com/sun/star/lib/uno/Proxy.java   
|3 +++
 jurt/com/sun/star/lib/uno/bridges/java_remote/BridgedObject.java   
|3 +++
 jurt/com/sun/star/lib/uno/bridges/java_remote/ProxyFactory.java
|3 +++
 jurt/com/sun/star/lib/uno/bridges/java_remote/RequestHandler.java  
|3 +++
 
jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionInputStream_Adapter.java
  |2 ++
 
jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionOutputStream_Adapter.java
 |2 ++
 jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java  
|3 +++
 jurt/com/sun/star/lib/uno/environments/java/java_environment.java  
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/IProtocol.java   
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/IReceiver.java   
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/IThreadPool.java 
|2 ++
 jurt/com/sun/star/lib/uno/environments/remote/JavaThreadPool.java  
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/JavaThreadPoolFactory.java   
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/Job.java 
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java
|2 ++
 jurt/com/sun/star/lib/uno/environments/remote/Message.java 
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/NativeThreadPool.java
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/ThreadId.java
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/ThreadPoolManager.java   
|3 +++
 jurt/com/sun/star/lib/uno/environments/remote/remote_environment.java  
|3 +++
 jurt/com/sun/star/lib/uno/protocols/urp/Cache.java 
|3 +++
 jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java   
|3 +++
 jurt/com/sun/star/lib/uno/protocols/urp/PendingRequests.java   
|3 +++
 jurt/com/sun/star/lib/uno/protocols/urp/Unmarshal.java 
|3 +++
 jurt/com/sun/star/lib/uno/protocols/urp/UrpMessage.java
|3 +++
 jurt/com/sun/star/lib/uno/protocols/urp/urp.java   
|3 +++
 jurt/com/sun/star/lib/util/AsynchronousFinalizer.java  
|3 +++
 jurt/com/sun/star/lib/util/NativeLibraryLoader.java
|3 +++
 jurt/com/sun/star/lib/util/StringHelper.java   
|3 +++
 jurt/com/sun/star/lib/util/UrlToFileMapper.java
|3 +++
 jurt/com/sun/star/uno/AnyConverter.java
|3 +++
 jurt/com/sun/star/uno/Ascii.java   
|2 ++
 jurt/com/sun/star/uno/AsciiString.java 
|2 ++
 jurt/com/sun/star

[Libreoffice-commits] core.git: jurt/com

2016-01-22 Thread Stephan Bergmann
 jurt/com/sun/star/lib/uno/protocols/urp/urp.java |4 +---
 1 file changed, 1 insertion(+), 3 deletions(-)

New commits:
commit cd9cafe54c87768ddde007228dc1d3f3b7e68f92
Author: Stephan Bergmann 
Date:   Fri Jan 22 12:47:47 2016 +0100

cid#1326191 is a false positive

and trying to appease Coverity with throwing a (checked---semantics 
attached!)
java.io.IOException is plain wrong.

Change-Id: Icece5ac74d482791d089f40ec201bc39d61db177

diff --git a/jurt/com/sun/star/lib/uno/protocols/urp/urp.java 
b/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
index cea15db..5e7b328 100644
--- a/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
+++ b/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
@@ -619,10 +619,8 @@ public final class urp implements IProtocol {
 for (int i = releaseQueue.size(); i > 0;) {
 --i;
 QueuedRelease r = releaseQueue.get(i);
-if (r == null)
-  throw new IOException("releaseQueue unexpected empty");
 writeRequest(
- r.internal, r.objectId, r.type, r.method, r.threadId, null,
+r.internal, r.objectId, r.type, r.method, r.threadId, null,
 false);
 releaseQueue.remove(i);
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com qadevOOo/tests

2016-01-22 Thread jan iversen
 jurt/com/sun/star/lib/uno/protocols/urp/urp.java|4 +++-
 qadevOOo/tests/java/ifc/accessibility/_XAccessibleText.java |7 +++
 2 files changed, 10 insertions(+), 1 deletion(-)

New commits:
commit e39bf3677109976cae13e1bdff044e2d5769c098
Author: jan iversen 
Date:   Thu Jan 21 19:54:46 2016 +0100

cid#1326191, 1326202

Null references elements, introduced throw

Change-Id: I22bf7de5f20c3ca455df31de2a5d7301b436ed82
Reviewed-on: https://gerrit.libreoffice.org/21691
Reviewed-by: Noel Grandin 
Tested-by: Noel Grandin 

diff --git a/jurt/com/sun/star/lib/uno/protocols/urp/urp.java 
b/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
index 5e7b328..cea15db 100644
--- a/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
+++ b/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
@@ -619,8 +619,10 @@ public final class urp implements IProtocol {
 for (int i = releaseQueue.size(); i > 0;) {
 --i;
 QueuedRelease r = releaseQueue.get(i);
+if (r == null)
+  throw new IOException("releaseQueue unexpected empty");
 writeRequest(
-r.internal, r.objectId, r.type, r.method, r.threadId, null,
+ r.internal, r.objectId, r.type, r.method, r.threadId, null,
 false);
 releaseQueue.remove(i);
 }
diff --git a/qadevOOo/tests/java/ifc/accessibility/_XAccessibleText.java 
b/qadevOOo/tests/java/ifc/accessibility/_XAccessibleText.java
index 9f4f5c0..92082d3 100644
--- a/qadevOOo/tests/java/ifc/accessibility/_XAccessibleText.java
+++ b/qadevOOo/tests/java/ifc/accessibility/_XAccessibleText.java
@@ -475,8 +475,15 @@ public class _XAccessibleText extends MultiMethodTest {
 } catch (com.sun.star.lang.IllegalArgumentException e) {
 }
 
+if (aRect == null) {
+res = false;
+log.print("aRect unexpected null");
+break;
+}
+
 int x = aRect.X + (aRect.Width / 2);
 int y = aRect.Y + (aRect.Height / 2);
+
 Point aPoint = new Point(x, y);
 int nIndex = oObj.getIndexAtPoint(aPoint);
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2015-12-22 Thread Caolán McNamara
 jurt/com/sun/star/lib/uno/protocols/urp/urp.java |4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

New commits:
commit 7653682c35eca35415aa0131c3df4a3d104d8c5d
Author: Caolán McNamara 
Date:   Tue Dec 22 20:30:34 2015 +

coverity#1326730 DMI: Dubious method invocation

Change-Id: Icf44c82fc485d0172df2a9fb2cbe6b2be61630a1

diff --git a/jurt/com/sun/star/lib/uno/protocols/urp/urp.java 
b/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
index b527e64..5e7b328 100644
--- a/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
+++ b/jurt/com/sun/star/lib/uno/protocols/urp/urp.java
@@ -199,7 +199,7 @@ public final class urp implements IProtocol {
 if (propertiesTid == null) {
 propertiesTid = ThreadId.createFresh();
 }
-random = new Random().nextInt();
+random = randomGenerator.nextInt();
 writeRequest(
 true, PROPERTIES_OID,
 TypeDescription.getTypeDescription(XProtocolProperties.class),
@@ -723,6 +723,8 @@ public final class urp implements IProtocol {
 
 private static final int MAX_RELEASE_QUEUE_SIZE = 100;
 
+private static final Random randomGenerator = new Random();
+
 private final DataInput input;
 private final DataOutputStream output;
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2015-10-15 Thread Noel Grandin
 jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java |   35 
--
 1 file changed, 16 insertions(+), 19 deletions(-)

New commits:
commit 846135c4c9eaedd18b2e01826860337c1b269664
Author: Noel Grandin 
Date:   Thu Oct 15 09:43:06 2015 +0200

use AtomicInteger for _life_count

(cid#1326323 Unguarded read)
Just switch this to an AtomicInteger, it's cheaper, and doesn't require 
synchronization,
so less chance of a deadlock.

This is an API change since this is a protected field in a public class, 
but anyone
messing with the internals of this class should have known better.

Change-Id: Idafc760c2e9d83442b8209ad23d180acb8dccb20

diff --git 
a/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java 
b/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java
index 0dcc75d..c949b55 100644
--- a/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java
+++ b/jurt/com/sun/star/lib/uno/bridges/java_remote/java_remote_bridge.java
@@ -26,33 +26,34 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.Map;
+import java.util.concurrent.atomic.AtomicInteger;
 
-import com.sun.star.lib.util.DisposeListener;
-import com.sun.star.lib.util.DisposeNotifier;
 import com.sun.star.bridge.XBridge;
 import com.sun.star.bridge.XInstanceProvider;
 import com.sun.star.connection.XConnection;
+import com.sun.star.lang.DisposedException;
 import com.sun.star.lang.EventObject;
 import com.sun.star.lang.XComponent;
 import com.sun.star.lang.XEventListener;
-import com.sun.star.lang.DisposedException;
 import com.sun.star.lib.uno.environments.java.java_environment;
 import com.sun.star.lib.uno.environments.remote.IProtocol;
 import com.sun.star.lib.uno.environments.remote.IReceiver;
+import com.sun.star.lib.uno.environments.remote.IThreadPool;
 import com.sun.star.lib.uno.environments.remote.Job;
 import com.sun.star.lib.uno.environments.remote.Message;
 import com.sun.star.lib.uno.environments.remote.ThreadId;
 import com.sun.star.lib.uno.environments.remote.ThreadPoolManager;
-import com.sun.star.lib.uno.environments.remote.IThreadPool;
 import com.sun.star.lib.uno.typedesc.MethodDescription;
 import com.sun.star.lib.uno.typedesc.TypeDescription;
+import com.sun.star.lib.util.DisposeListener;
+import com.sun.star.lib.util.DisposeNotifier;
+import com.sun.star.uno.Any;
 import com.sun.star.uno.IBridge;
 import com.sun.star.uno.IEnvironment;
-import com.sun.star.uno.UnoRuntime;
-import com.sun.star.uno.XInterface;
 import com.sun.star.uno.Type;
 import com.sun.star.uno.TypeClass;
-import com.sun.star.uno.Any;
+import com.sun.star.uno.UnoRuntime;
+import com.sun.star.uno.XInterface;
 
 /**
  * This class implements a remote bridge.
@@ -156,7 +157,7 @@ public class java_remote_bridge
 protected IProtocol _iProtocol;
 protected IEnvironment  _java_environment;
 protected MessageDispatcher _messageDispatcher;
-protected int   _life_count = 0;// determines if this 
bridge is alive, which is controlled by acquire and release calls
+protected final AtomicInteger _life_count = new AtomicInteger();// 
determines if this bridge is alive, which is controlled by acquire and release 
calls
 
 private final ArrayList _listeners = new 
ArrayList();
 
@@ -169,7 +170,7 @@ public class java_remote_bridge
  * This method is for testing only.
  */
 int getLifeCount() {
-return _life_count;
+return _life_count.get();
 }
 
 /**
@@ -447,10 +448,10 @@ public class java_remote_bridge
  *
  * @see com.sun.star.uno.IBridge#acquire
  */
-public synchronized void acquire() {
-++ _life_count;
+public void acquire() {
+int x = _life_count.incrementAndGet();
 
-if(DEBUG) System.err.println("# " + getClass().getName() + 
".acquire:" + _life_count);
+if(DEBUG) System.err.println("# " + getClass().getName() + 
".acquire:" + x);
 }
 
 /**
@@ -461,12 +462,8 @@ public class java_remote_bridge
  * @see com.sun.star.uno.IBridge#release
  */
 public void release() {
-boolean dispose;
-synchronized (this) {
---_life_count;
-dispose = _life_count <= 0;
-}
-if (dispose) {
+int x = _life_count.decrementAndGet();
+if (x <= 0) {
 dispose(new Throwable("end of life"));
 }
 }
@@ -521,7 +518,7 @@ public class java_remote_bridge
 proxyFactory.dispose();
 
 if (DEBUG) {
-if (_life_count != 0) {
+if (_life_count.get() != 0) {
 System.err.println(getClass().getName()
+ ".dispose - life count (proxies 
left):"
+ _life_count);
___
Libreoffice-commits mailing list
libreoffice-comm...@

[Libreoffice-commits] core.git: jurt/com

2015-07-31 Thread Noel Grandin
 jurt/com/sun/star/lib/connections/socket/socketAcceptor.java  |5 -
 jurt/com/sun/star/lib/connections/socket/socketConnector.java |4 +++-
 2 files changed, 7 insertions(+), 2 deletions(-)

New commits:
commit 9ffdcc76858bc01150727345de4dfd0ef40ed8c0
Author: Noel Grandin 
Date:   Thu Jul 30 15:38:41 2015 +0200

fix use of TCP_NODELAY for localhost URP connections

we implemented this logic in the C++ URP code a while back, but the Java
code was not correctly updated.

Change-Id: I377d7150f1adb69d6f86d9b4f3406163aaf85aea
Reviewed-on: https://gerrit.libreoffice.org/17427
Reviewed-by: Noel Grandin 
Tested-by: Noel Grandin 

diff --git a/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java 
b/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java
index 022f891..da33625 100644
--- a/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java
+++ b/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java
@@ -152,9 +152,12 @@ public final class socketAcceptor implements XAcceptor {
 }
 // we enable tcpNoDelay for loopback connections because
 // it can make a significant speed difference on linux boxes.
-if (tcpNoDelay != null || 
((InetSocketAddress)socket.getRemoteSocketAddress()).getAddress().isLoopbackAddress())
 {
+if (tcpNoDelay != null) {
 socket.setTcpNoDelay(tcpNoDelay.booleanValue());
 }
+else if 
(((InetSocketAddress)socket.getRemoteSocketAddress()).getAddress().isLoopbackAddress())
 {
+socket.setTcpNoDelay(true);
+}
 return new SocketConnection(acceptingDescription, socket);
 }
 catch(IOException e) {
diff --git a/jurt/com/sun/star/lib/connections/socket/socketConnector.java 
b/jurt/com/sun/star/lib/connections/socket/socketConnector.java
index fc44639..c169b59 100644
--- a/jurt/com/sun/star/lib/connections/socket/socketConnector.java
+++ b/jurt/com/sun/star/lib/connections/socket/socketConnector.java
@@ -146,8 +146,10 @@ public final class socketConnector implements XConnector {
 try {
 // we enable tcpNoDelay for loopback connections because
 // it can make a significant speed difference on linux boxes.
-if (desc.getTcpNoDelay() != null || isLoopbackAddress)
+if (desc.getTcpNoDelay() != null)
 socket.setTcpNoDelay(desc.getTcpNoDelay().booleanValue());
+else if (isLoopbackAddress)
+socket.setTcpNoDelay(true);
 
 con = new SocketConnection(connectionDescription, socket);
 } catch (IOException e) {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com jvmfwk/plugins lotuswordpro/source odk/config odk/docs odk/examples offapi/com offapi/type_reference officecfg/registry oox/inc oox/source package/source qadev

2015-07-03 Thread Andrea Gelmini
 jurt/com/sun/star/uno/AnyConverter.java
  |2 +-
 jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx
  |2 +-
 jvmfwk/plugins/sunmajor/pluginlib/util.cxx 
  |2 +-
 lotuswordpro/source/filter/lwpcelllayout.cxx   
  |2 +-
 lotuswordpro/source/filter/lwpfribheader.hxx   
  |2 +-
 lotuswordpro/source/filter/lwplayout.cxx   
  |2 +-
 lotuswordpro/source/filter/lwppara.cxx 
  |2 +-
 lotuswordpro/source/filter/lwpstory.cxx
  |4 ++--
 lotuswordpro/source/filter/lwptablelayout.cxx  
  |2 +-
 lotuswordpro/source/filter/lwpuidoc.hxx
  |2 +-
 lotuswordpro/source/filter/xfilter/xffont.cxx  
  |2 +-
 lotuswordpro/source/filter/xfilter/xffontfactory.hxx   
  |2 +-
 lotuswordpro/source/filter/xfilter/xfframe.hxx 
  |2 +-
 odk/config/configure.pl
  |2 +-
 odk/docs/idl/wikilinks.py  
  |2 +-
 odk/examples/DevelopersGuide/Config/ConfigExamples.java
  |2 +-
 odk/examples/DevelopersGuide/Forms/SalesFilter.java
  |2 +-
 odk/examples/DevelopersGuide/GUI/UnoMenu.java  
  |2 +-
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java  
  |6 +++---
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/IOnewayLink.java 
  |2 +-
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Interceptor.java 
  |4 ++--
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java  
  |2 +-
 
odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
 |6 +++---
 
odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java
  |2 +-
 odk/examples/DevelopersGuide/OfficeDev/PathSettings/PathSettingsTest.java  
  |4 ++--
 odk/examples/java/Text/TextDocumentStructure.java  
  |2 +-
 offapi/com/sun/star/ucb/Content.idl
  |4 ++--
 offapi/type_reference/typelibrary_history.txt  
  |2 +-
 officecfg/registry/schema/org/openoffice/TypeDetection/GraphicFilter.xcs   
  |2 +-
 oox/inc/drawingml/chart/axismodel.hxx  
  |2 +-
 oox/source/core/binarycodec.cxx
  |2 +-
 oox/source/ppt/pptfilterhelpers.cxx
  |2 +-
 package/source/xstor/xstorage.cxx  
  |2 +-
 qadevOOo/runner/base/java_complex.java 
  |2 +-
 qadevOOo/runner/complexlib/ComplexTestCase.java
  |6 +++---
 qadevOOo/runner/helper/LoggingThread.java  
  |2 +-
 qadevOOo/runner/lib/SimpleStatus.java  
  |4 ++--
 qadevOOo/runner/lib/TestResult.java
  |4 ++--
 qadevOOo/runner/stats/Summarizer.java  
  |2 +-
 qadevOOo/runner/util/UITools.java  
  |2 +-
 qadevOOo/runner/util/XMLTools.java 
  |2 +-
 qadevOOo/runner/util/utils.java
  |2 +-
 qadevOOo/tests/java/complex/unoapi/CheckModuleAPI.java 
  |2 +-
 qadevOOo/tests/java/ifc/awt/tree/_XTreeNode.java   
  |2 +-
 qadevOOo/tests/java/ifc/beans/_XPropertyAccess.java
  |4 ++--
 qadevOOo/tests/java/ifc/beans/_XPropertyState.java 
  |2 +-
 qadevOOo/tests/java/ifc/datatransfer/_XDataFormatTranslator.java   
  |2 +-
 qadevOOo/tests/java/ifc/datatransfe

[Libreoffice-commits] core.git: jurt/com

2014-10-27 Thread Stephan Bergmann
 jurt/com/sun/star/lib/util/UrlToFileMapper.java |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit d0a8fc24b351517ff4255e93fb1c8a78391facf7
Author: Stephan Bergmann 
Date:   Mon Oct 27 15:09:02 2014 +0100

Fix indentation

Change-Id: Ic058759782f95e330d8c581911aeb163340a7c4b

diff --git a/jurt/com/sun/star/lib/util/UrlToFileMapper.java 
b/jurt/com/sun/star/lib/util/UrlToFileMapper.java
index 3380992..87b27c6 100644
--- a/jurt/com/sun/star/lib/util/UrlToFileMapper.java
+++ b/jurt/com/sun/star/lib/util/UrlToFileMapper.java
@@ -82,10 +82,10 @@ public final class UrlToFileMapper {
 } catch (UnsupportedEncodingException e) {
 throw new RuntimeException(e); // should never happen
 }
- }
- }
+}
+}
 return buf.toString();
- }
+}
 
- private UrlToFileMapper() {}
+private UrlToFileMapper() {}
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-10-14 Thread Robert Antoni Buj i Gelonch
 jurt/com/sun/star/lib/connections/socket/SocketConnection.java |7 +--
 1 file changed, 5 insertions(+), 2 deletions(-)

New commits:
commit 530f060e41aa28634c133dab2e606907010d3cc3
Author: Robert Antoni Buj i Gelonch 
Date:   Tue Oct 14 11:25:26 2014 +0200

jurt: print an array with java.util.Arrays.toString

Change-Id: I76431b67f9f6fdde2906d6d8082457ef0847108e
Reviewed-on: https://gerrit.libreoffice.org/11964
Reviewed-by: Noel Grandin 
Tested-by: Noel Grandin 

diff --git a/jurt/com/sun/star/lib/connections/socket/SocketConnection.java 
b/jurt/com/sun/star/lib/connections/socket/SocketConnection.java
index f7ad911..6f2a548 100644
--- a/jurt/com/sun/star/lib/connections/socket/SocketConnection.java
+++ b/jurt/com/sun/star/lib/connections/socket/SocketConnection.java
@@ -23,8 +23,11 @@ import java.io.BufferedOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+
 import java.net.Socket;
+
 import java.util.ArrayList;
+import java.util.Arrays;
 
 import com.sun.star.connection.XConnection;
 import com.sun.star.connection.XConnectionBroadcaster;
@@ -154,7 +157,7 @@ public class SocketConnection implements XConnection, 
XConnectionBroadcaster {
 throw unoIOException;
 }
 
-if (DEBUG) System.err.println("# " + getClass().getName() + " - 
read byte:" + read_bytes + " " + bytes[0]);
+if (DEBUG) System.err.println("# " + getClass().getName() + " - 
read byte:" + read_bytes + " " + Arrays.toString(bytes[0]));
 
 return read_bytes;
 }
@@ -176,7 +179,7 @@ public class SocketConnection implements XConnection, 
XConnectionBroadcaster {
 throw unoIOException;
 }
 
-if (DEBUG) System.err.println("# " + getClass().getName() + " - 
written bytes:" + aData + " " + aData.length);
+if (DEBUG) System.err.println("# " + getClass().getName() + " - 
written bytes:" + Arrays.toString(aData) + " " + aData.length);
 }
 
 /**
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-10-09 Thread Robert Antoni Buj i Gelonch
 jurt/com/sun/star/comp/bridgefactory/BridgeFactory.java   |5 ---
 jurt/com/sun/star/comp/loader/JavaLoader.java |   20 ++
 jurt/com/sun/star/comp/servicemanager/ServiceManager.java |6 
 3 files changed, 6 insertions(+), 25 deletions(-)

New commits:
commit 7afbb8275667ca8157be5449536e671bbac9f988
Author: Robert Antoni Buj i Gelonch 
Date:   Thu Oct 9 20:53:02 2014 +0200

jurt: use new exception constructors

Change-Id: I58e7ebdd5c48094142f93f47271bcc0cc8b97981
Reviewed-on: https://gerrit.libreoffice.org/11892
Reviewed-by: Noel Grandin 
Tested-by: Noel Grandin 

diff --git a/jurt/com/sun/star/comp/bridgefactory/BridgeFactory.java 
b/jurt/com/sun/star/comp/bridgefactory/BridgeFactory.java
index 7e370a9..7dd6fcf 100644
--- a/jurt/com/sun/star/comp/bridgefactory/BridgeFactory.java
+++ b/jurt/com/sun/star/comp/bridgefactory/BridgeFactory.java
@@ -124,10 +124,7 @@ public class BridgeFactory implements XBridgeFactory/*, 
XEventListener*/ {
 xBridge = UnoRuntime.queryInterface(XBridge.class, iBridge);
 }
 catch (Exception e) {
-com.sun.star.lang.IllegalArgumentException e2 =
-new com.sun.star.lang.IllegalArgumentException(e.getMessage());
-e2.initCause(e);
-throw e2;
+throw new com.sun.star.lang.IllegalArgumentException(e, 
e.getMessage());
 }
 
 if(DEBUG) System.err.println("# " + getClass().getName() + 
".createBridge:" + sName + " " + sProtocol + " " + aConnection + " "  + 
anInstanceProvider + " " + xBridge);
diff --git a/jurt/com/sun/star/comp/loader/JavaLoader.java 
b/jurt/com/sun/star/comp/loader/JavaLoader.java
index 7649d10..fb7c6d8 100644
--- a/jurt/com/sun/star/comp/loader/JavaLoader.java
+++ b/jurt/com/sun/star/comp/loader/JavaLoader.java
@@ -279,20 +279,11 @@ public class JavaLoader implements XImplementationLoader,
 }
 }
 } catch (java.net.MalformedURLException e) {
-CannotActivateFactoryException cae = new 
CannotActivateFactoryException(
-"Can not activate factory because " + e );
-cae.initCause(e);
-throw cae;
+throw new CannotActivateFactoryException(e, "Can not activate 
factory because " + e);
 } catch (java.io.IOException e) {
-CannotActivateFactoryException cae = new 
CannotActivateFactoryException(
-"Can not activate factory because " + e );
-cae.initCause(e);
-throw cae;
+throw new CannotActivateFactoryException(e, "Can not activate 
factory because " + e);
 } catch (java.lang.ClassNotFoundException e) {
-CannotActivateFactoryException cae = new 
CannotActivateFactoryException(
-"Can not activate factory because " + e );
-cae.initCause(e);
-throw cae;
+throw new CannotActivateFactoryException(e, "Can not activate 
factory because " + e);
 }
 
 Class[] paramTypes = {String.class, XMultiServiceFactory.class, 
XRegistryKey.class};
@@ -400,10 +391,7 @@ public class JavaLoader implements XImplementationLoader,
 if ( (oRet != null) && (oRet instanceof Boolean) )
 success = ((Boolean) oRet).booleanValue();
 } catch (Exception e) {
-CannotRegisterImplementationException e2 =
-new CannotRegisterImplementationException(e.toString());
-e2.initCause(e);
-throw e2;
+throw new CannotRegisterImplementationException(e, e.toString());
  }
 
 return success;
diff --git a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java 
b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
index 729fda5..85f69fd 100644
--- a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
+++ b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
@@ -652,11 +652,7 @@ public class ServiceManager implements 
XMultiServiceFactory,
 try {
 return enumeration.next();
 } catch (java.util.NoSuchElementException e) {
-com.sun.star.container.NoSuchElementException ex =
-new com.sun.star.container.NoSuchElementException(
-e.toString());
-ex.initCause(e);
-throw ex;
+throw new com.sun.star.container.NoSuchElementException(e, 
e.toString());
 }
 }
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-10-08 Thread Robert Antoni Buj i Gelonch
 jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java |1 -
 1 file changed, 1 deletion(-)

New commits:
commit c2b5affc135a3dd202b8d9ca3a4317a1d05203cd
Author: Robert Antoni Buj i Gelonch 
Date:   Wed Oct 8 22:24:19 2014 +0200

jurt: remove unused import

Change-Id: I597dac3cae7eafef75982789ab1b0d3d8d6999d2
Reviewed-on: https://gerrit.libreoffice.org/11863
Reviewed-by: Samuel Mehrbrodt 
Tested-by: Samuel Mehrbrodt 

diff --git a/jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java 
b/jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java
index 8a42b4a..c226e3a 100644
--- a/jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java
+++ b/jurt/com/sun/star/lib/uno/protocols/urp/Marshal.java
@@ -31,7 +31,6 @@ import java.io.ByteArrayOutputStream;
 import java.io.DataOutput;
 import java.io.DataOutputStream;
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 import java.lang.reflect.Array;
 import java.lang.reflect.InvocationTargetException;
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-09-29 Thread Noel Grandin
 
jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionInputStream_Adapter.java
  |   10 +---
 
jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionOutputStream_Adapter.java
 |   12 +++---
 2 files changed, 15 insertions(+), 7 deletions(-)

New commits:
commit d5cdc7567299f03e655dfbb1d59c371fb3253b88
Author: Noel Grandin 
Date:   Mon Sep 29 11:30:07 2014 +0200

fix Java1.5 incompatibility

the java.io.IOException(Throwable) constructor was only introduced
in 1.6

Change-Id: Icd40e91cce7a2e89e4a70ad55f31baaa86eebfe2

diff --git 
a/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionInputStream_Adapter.java
 
b/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionInputStream_Adapter.java
index 48fea08..7f65c3b 100644
--- 
a/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionInputStream_Adapter.java
+++ 
b/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionInputStream_Adapter.java
@@ -46,7 +46,9 @@ class XConnectionInputStream_Adapter extends InputStream {
 try {
 len = _xConnection.read(_bytes, 1);
 } catch(com.sun.star.io.IOException ioException) {
-throw new IOException(ioException);
+IOException ex = new IOException(ioException.getMessage());
+ex.initCause(ioException);
+throw ex;
 }
 
 if(DEBUG) System.err.println(" " + getClass().getName()  + " - one 
byte read:" +  _bytes[0][0]);
@@ -56,12 +58,12 @@ class XConnectionInputStream_Adapter extends InputStream {
 
 @Override
 public int read(byte[] b, int off, int len) throws IOException {
-//  byte bytes[][] = new byte[1][];
-
 try {
 len = _xConnection.read(_bytes, len - off);
 } catch(com.sun.star.io.IOException ioException) {
-throw new IOException(ioException);
+IOException ex = new IOException(ioException.getMessage());
+ex.initCause(ioException);
+throw ex;
 }
 
 System.arraycopy(_bytes[0], 0, b, off, len);
diff --git 
a/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionOutputStream_Adapter.java
 
b/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionOutputStream_Adapter.java
index 954afe8..fe97074 100644
--- 
a/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionOutputStream_Adapter.java
+++ 
b/jurt/com/sun/star/lib/uno/bridges/java_remote/XConnectionOutputStream_Adapter.java
@@ -44,7 +44,9 @@ class XConnectionOutputStream_Adapter extends OutputStream {
 try {
 _xConnection.write(_bytes);
 } catch(com.sun.star.io.IOException ioException) {
-throw new IOException(ioException);
+IOException ex = new IOException(ioException.getMessage());
+ex.initCause(ioException);
+throw ex;
 }
 
 if(DEBUG) System.err.println(" " + this.getClass()  + " - one byte 
written:" +  _bytes[0]);
@@ -65,7 +67,9 @@ class XConnectionOutputStream_Adapter extends OutputStream {
 try {
 _xConnection.write(bytes);
 } catch(com.sun.star.io.IOException ioException) {
-throw new IOException(ioException);
+IOException ex = new IOException(ioException.getMessage());
+ex.initCause(ioException);
+throw ex;
 }
 }
 
@@ -74,7 +78,9 @@ class XConnectionOutputStream_Adapter extends OutputStream {
 try {
 _xConnection.flush();
 } catch(com.sun.star.io.IOException ioException) {
-throw new IOException(ioException);
+IOException ex = new IOException(ioException.getMessage());
+ex.initCause(ioException);
+throw ex;
 }
 }
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-09-14 Thread rbuj
 jurt/com/sun/star/comp/loader/JavaLoader.java |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 5c2d2d087f22b00a8447d1d97de353242e89deab
Author: rbuj 
Date:   Sun Sep 14 15:27:59 2014 +0200

jurt: encode(String) in URLEncoder has been deprecated

Change-Id: I914985aa73653e0fb08200ddd06ad5b914087e3a
Reviewed-on: https://gerrit.libreoffice.org/11446
Reviewed-by: Noel Grandin 
Tested-by: Noel Grandin 

diff --git a/jurt/com/sun/star/comp/loader/JavaLoader.java 
b/jurt/com/sun/star/comp/loader/JavaLoader.java
index c82f8e9..4298d0b 100644
--- a/jurt/com/sun/star/comp/loader/JavaLoader.java
+++ b/jurt/com/sun/star/comp/loader/JavaLoader.java
@@ -109,7 +109,7 @@ public class JavaLoader implements XImplementationLoader,
 String macro = URLDecoder.decode(
 StringHelper.replace(
 url.substring( EXPAND_PROTOCOL_PREFIX.length() ),
-'+', "%2B" ) );
+'+', "%2B" ), "UTF-8" );
 // expand macro string
 String ret = m_xMacroExpander.expandMacros( macro );
 if (DEBUG) {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-09-02 Thread rbuj
 jurt/com/sun/star/comp/connections/Implementation.java |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 66d031649e8cb1716b7eaac0f7c31956fdbc62ec
Author: rbuj 
Date:   Mon Sep 1 20:02:01 2014 +0200

jurt: fix javadoc error: unexpected end tag: 

Change-Id: Ie8eb163793dc575558149320dceffcd92bdcfdd4
Reviewed-on: https://gerrit.libreoffice.org/11245
Reviewed-by: Thomas Arnhold 
Tested-by: Thomas Arnhold 

diff --git a/jurt/com/sun/star/comp/connections/Implementation.java 
b/jurt/com/sun/star/comp/connections/Implementation.java
index 49aba66..6dfea58 100644
--- a/jurt/com/sun/star/comp/connections/Implementation.java
+++ b/jurt/com/sun/star/comp/connections/Implementation.java
@@ -40,7 +40,7 @@ final class Implementation {
  * -->
  * (with type in lower case, and
  * service either Acceptor or
- * Connector).
+ * Connector).
  * @param serviceClass the IDL interface type for which to query the
  * requested service.
  * @param serviceType must be either Acceptor or
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-08-30 Thread rbuj
 jurt/com/sun/star/lib/connections/pipe/pipeAcceptor.java  |4 ++--
 jurt/com/sun/star/lib/connections/pipe/pipeConnector.java |4 ++--
 jurt/com/sun/star/lib/connections/socket/socketAcceptor.java  |4 ++--
 jurt/com/sun/star/lib/connections/socket/socketConnector.java |4 ++--
 jurt/com/sun/star/lib/uno/environments/remote/Message.java|4 ++--
 5 files changed, 10 insertions(+), 10 deletions(-)

New commits:
commit dc64ffbf9e3cf24cebbb454e6b75a0a69656ceb8
Author: rbuj 
Date:   Fri Aug 29 14:00:45 2014 +0200

jurt: fix some javadoc errors for JDK 8

Change-Id: I998f5796d7a5f10f790a1e861b741c54d0f62c19
Reviewed-on: https://gerrit.libreoffice.org/11191
Reviewed-by: Noel Grandin 
Tested-by: Noel Grandin 

diff --git a/jurt/com/sun/star/lib/connections/pipe/pipeAcceptor.java 
b/jurt/com/sun/star/lib/connections/pipe/pipeAcceptor.java
index a8dd0ad..52e00a4 100644
--- a/jurt/com/sun/star/lib/connections/pipe/pipeAcceptor.java
+++ b/jurt/com/sun/star/lib/connections/pipe/pipeAcceptor.java
@@ -83,7 +83,7 @@ public final class pipeAcceptor implements XAcceptor {
  * type*(key=value),
  * where type should be pipe
- * (ignoring case).  Supported keys (ignoring case) currently are
+ * (ignoring case).  Supported keys (ignoring case) currently are
  * 
  * host
  * The name or address of the accepting interface (defaults to
@@ -96,7 +96,7 @@ public final class pipeAcceptor implements XAcceptor {
  * tcpnodelay
  * A flag (0/1) enabling or disabling Nagle's
  * algorithm on the resulting connection.
- * 
+ * 
  *
  * @param connectionDescription the description of the connection.
  * @return an XConnection to the client.
diff --git a/jurt/com/sun/star/lib/connections/pipe/pipeConnector.java 
b/jurt/com/sun/star/lib/connections/pipe/pipeConnector.java
index 425128c..95c064e 100644
--- a/jurt/com/sun/star/lib/connections/pipe/pipeConnector.java
+++ b/jurt/com/sun/star/lib/connections/pipe/pipeConnector.java
@@ -81,7 +81,7 @@ public final class pipeConnector implements XConnector {
  * type*(key=value),
  * where type should be pipe
- * (ignoring case).  Supported keys (ignoring case) currently are
+ * (ignoring case).  Supported keys (ignoring case) currently are
  * 
  * host
  * The name or address of the server.  Must be present.
@@ -90,7 +90,7 @@ public final class pipeConnector implements XConnector {
  * tcpnodelay
  * A flag (0/1) enabling or disabling Nagle's
  * algorithm on the resulting connection.
- * 
+ * 
  *
  * @param connectionDescription the description of the connection.
  * @return an XConnection to the server.
diff --git a/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java 
b/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java
index 22dbfa4..4902d52 100644
--- a/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java
+++ b/jurt/com/sun/star/lib/connections/socket/socketAcceptor.java
@@ -88,7 +88,7 @@ public final class socketAcceptor implements XAcceptor {
  * type*(key=value),
  * where type should be socket
- * (ignoring case).  Supported keys (ignoring case) currently are
+ * (ignoring case).  Supported keys (ignoring case) currently are
  * 
  * host
  * The name or address of the accepting interface (defaults to
@@ -101,7 +101,7 @@ public final class socketAcceptor implements XAcceptor {
  * tcpnodelay
  * A flag (0/1) enabling or disabling Nagle's
  * algorithm on the resulting connection.
- * 
+ * 
  *
  * @param connectionDescription the description of the connection.
  * @return an XConnection to the client.
diff --git a/jurt/com/sun/star/lib/connections/socket/socketConnector.java 
b/jurt/com/sun/star/lib/connections/socket/socketConnector.java
index 48d87b7..ce76eaa 100644
--- a/jurt/com/sun/star/lib/connections/socket/socketConnector.java
+++ b/jurt/com/sun/star/lib/connections/socket/socketConnector.java
@@ -86,7 +86,7 @@ public final class socketConnector implements XConnector {
  * type*(key=value),
  * where type should be socket
- * (ignoring case).  Supported keys (ignoring case) currently are
+ * (ignoring case).  Supported keys (ignoring case) currently are
  * 
  * host
  * The name or address of the server.  Must be present.
@@ -95,7 +95,7 @@ public final class socketConnector implements XConnector {
  * tcpnodelay
  * A flag (0/1) enabling or disabling Nagle's
  * algorithm on the resulting connection.
- * 
+ * 
  *
  * @param connectionDescription the description of the connection.
  * @return an XConnection to the server.
diff --git a/jurt/com/sun/star/lib/uno/environments/remote/Message.java 
b/jurt/com/sun/star/lib/uno/environments/remote/Message.java
index f679d76..cfdd1f3 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/Message.java
++

[Libreoffice-commits] core.git: jurt/com

2014-08-19 Thread rbuj
 jurt/com/sun/star/comp/loader/FactoryHelper.java   |4 ++--
 jurt/com/sun/star/comp/loader/JavaLoader.java  |2 +-
 jurt/com/sun/star/lib/uno/environments/remote/Job.java |2 +-
 3 files changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 37c49c305852f4a58e010c63331ba302462754d9
Author: rbuj 
Date:   Tue Aug 19 21:34:58 2014 +0200

jurt: Throwable.getCause() instead of Throwable.getTargetException()

As of the JDK 1.4, Throwable.getCause() is the preferred method for getting 
thrown target exception.

Change-Id: I14f3f9ae52869d1149f92b32562e7fb3293109b5
Reviewed-on: https://gerrit.libreoffice.org/11027
Reviewed-by: Noel Grandin 
Tested-by: Noel Grandin 

diff --git a/jurt/com/sun/star/comp/loader/FactoryHelper.java 
b/jurt/com/sun/star/comp/loader/FactoryHelper.java
index 2a71201..92b4801 100644
--- a/jurt/com/sun/star/comp/loader/FactoryHelper.java
+++ b/jurt/com/sun/star/comp/loader/FactoryHelper.java
@@ -198,7 +198,7 @@ public class FactoryHelper {
 try {
 return _constructor.newInstance( args );
 } catch (InvocationTargetException invocationTargetException) {
-Throwable targetException = 
invocationTargetException.getTargetException();
+Throwable targetException = 
invocationTargetException.getCause();
 
 if (targetException instanceof java.lang.RuntimeException)
 throw (java.lang.RuntimeException)targetException;
@@ -274,7 +274,7 @@ public class FactoryHelper {
 }
 return instance;
 } catch (InvocationTargetException invocationTargetException) {
-Throwable targetException = 
invocationTargetException.getTargetException();
+Throwable targetException = 
invocationTargetException.getCause();
 
 if (targetException instanceof java.lang.RuntimeException)
 throw (java.lang.RuntimeException)targetException;
diff --git a/jurt/com/sun/star/comp/loader/JavaLoader.java 
b/jurt/com/sun/star/comp/loader/JavaLoader.java
index d7f757a..c82f8e9 100644
--- a/jurt/com/sun/star/comp/loader/JavaLoader.java
+++ b/jurt/com/sun/star/comp/loader/JavaLoader.java
@@ -353,7 +353,7 @@ public class JavaLoader implements XImplementationLoader,
 + implementationName + " because " + e.toString() );
 } catch ( InvocationTargetException e ) {
 throw new CannotActivateFactoryException("Can not activate the 
factory for "
-+ implementationName + " because " + 
e.getTargetException().toString() );
++ implementationName + " because " + 
e.getCause().toString() );
 }
 
 return returnObject;
diff --git a/jurt/com/sun/star/lib/uno/environments/remote/Job.java 
b/jurt/com/sun/star/lib/uno/environments/remote/Job.java
index 47fc033..1d8b366 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/Job.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/Job.java
@@ -90,7 +90,7 @@ public class Job {
 ? dispatch_queryInterface((Type) args[0])
 : md.getMethod().invoke(_object, args);
 } catch (InvocationTargetException e) {
-exception = e.getTargetException();
+exception = e.getCause();
 if (exception == null) {
 exception = e;
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-08-10 Thread rbuj
 jurt/com/sun/star/comp/servicemanager/ServiceManager.java |   15 +-
 1 file changed, 6 insertions(+), 9 deletions(-)

New commits:
commit 85ab4a14c541f3d6c30300d102b97f8564a1c7ee
Author: rbuj 
Date:   Sun Aug 10 03:10:29 2014 +0200

jurt: Use  T[] toArray(T[] a)


http://docs.oracle.com/javase/1.5.0/docs/api/java/util/Set.html#toArray%28T%5b%5d%29

Change-Id: I601e77db3cc978d81aebddfe6abba1c020671913
Reviewed-on: https://gerrit.libreoffice.org/10853
Reviewed-by: David Tardon 
Tested-by: David Tardon 

diff --git a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java 
b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
index a4a5f8d..38e5cb3 100644
--- a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
+++ b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
@@ -188,15 +188,12 @@ public class ServiceManager implements 
XMultiServiceFactory,
 public String[] getAvailableServiceNames()
 throws com.sun.star.uno.RuntimeException
 {
-int i = 0;
-String[] availableServiceNames = new 
String[factoriesByServiceNames.size()];
-
-java.util.Iterator keys = 
factoriesByServiceNames.keySet().iterator();
-
-while (keys.hasNext())
-availableServiceNames[i++] = keys.next();
-
-return availableServiceNames;
+try{
+return factoriesByServiceNames.keySet().toArray(
+new String[ factoriesByServiceNames.size() ] );
+} catch(Exception ex) {
+throw new com.sun.star.uno.RuntimeException(ex.toString());
+}
 }
 
 // XMultiComponentFactory implementation
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-08-09 Thread rbuj
 jurt/com/sun/star/lib/connections/socket/ConnectionDescriptor.java |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit bb8540a3b4fe0798669a1d355695c97d86ef58a0
Author: rbuj 
Date:   Sat Aug 9 14:45:51 2014 +0200

jurt: Number parsing

Change-Id: I40721bdaae62f063c188546fedb4037e40f890fa
Reviewed-on: https://gerrit.libreoffice.org/10845
Reviewed-by: David Tardon 
Tested-by: David Tardon 

diff --git a/jurt/com/sun/star/lib/connections/socket/ConnectionDescriptor.java 
b/jurt/com/sun/star/lib/connections/socket/ConnectionDescriptor.java
index f362dac..aec6a63 100644
--- a/jurt/com/sun/star/lib/connections/socket/ConnectionDescriptor.java
+++ b/jurt/com/sun/star/lib/connections/socket/ConnectionDescriptor.java
@@ -43,7 +43,7 @@ final class ConnectionDescriptor {
 host = value;
 } else if (key.equalsIgnoreCase("port")) {
 try {
-port = Integer.valueOf(value).intValue();
+port = Integer.parseInt(value);
 } catch (NumberFormatException e) {
 throw new com.sun.star.lang.IllegalArgumentException(
 e.toString());
@@ -55,7 +55,7 @@ final class ConnectionDescriptor {
 }
 } else if (key.equalsIgnoreCase("backlog")) {
 try {
-backlog = Integer.valueOf(value).intValue();
+backlog = Integer.parseInt(value);
 } catch (NumberFormatException e) {
 throw new com.sun.star.lang.IllegalArgumentException(
 e.toString());
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com qadevOOo/tests

2014-08-04 Thread Noel Grandin
 jurt/com/sun/star/comp/loader/FactoryHelper.java   |   21 
++
 qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java |6 --
 2 files changed, 7 insertions(+), 20 deletions(-)

New commits:
commit dc2cd08af181e8f29ac403a242a15cf4cf7a5bd2
Author: Noel Grandin 
Date:   Mon Aug 4 10:10:02 2014 +0200

simplify some java static initializers

Change-Id: Ic767b655297bfb5fcfb5cd7878d7131a9cb6b2f1

diff --git a/jurt/com/sun/star/comp/loader/FactoryHelper.java 
b/jurt/com/sun/star/comp/loader/FactoryHelper.java
index 191aa1d..64ef51f 100644
--- a/jurt/com/sun/star/comp/loader/FactoryHelper.java
+++ b/jurt/com/sun/star/comp/loader/FactoryHelper.java
@@ -55,17 +55,6 @@ public class FactoryHelper {
 static protected class Factory
 implements XSingleServiceFactory, XSingleComponentFactory, 
XServiceInfo,
 XTypeProvider {
-protected static Class __objectArray;
-
-static {
-try {
-__objectArray = Class.forName("[Ljava.lang.Object;");
-}
-catch(ClassNotFoundException classNotFoundException) {
-System.err.println(FactoryHelper.class.getName() + " exception 
occurred - " + classNotFoundException);
-}
-}
-
 //private static final boolean DEBUG = false;
 
 protected XMultiServiceFactory _xMultiServiceFactory;
@@ -92,7 +81,7 @@ public class FactoryHelper {
 if(parameters.length == 3
&& parameters[0].equals(XComponentContext.class)
  && parameters[1].equals(XRegistryKey.class)
- && parameters[2].equals(__objectArray)) {
+ && parameters[2].equals(Object[].class)) {
 _nCode = 0;
 _constructor = constructors[i];
 }
@@ -104,7 +93,7 @@ public class FactoryHelper {
 }
 else if(parameters.length == 2
  && parameters[0].equals(XComponentContext.class)
- && parameters[1].equals(__objectArray)) {
+ && parameters[1].equals(Object[].class)) {
 _nCode = 2;
 _constructor = constructors[i];
 }
@@ -117,7 +106,7 @@ public class FactoryHelper {
 else if(parameters.length == 3
  && parameters[0].equals(XMultiServiceFactory.class)
  && parameters[1].equals(XRegistryKey.class)
- && parameters[2].equals(__objectArray)) {
+ && parameters[2].equals(Object[].class)) {
 _nCode = 4;
 _constructor = constructors[i];
 }
@@ -129,7 +118,7 @@ public class FactoryHelper {
 }
 else if(parameters.length == 2
  && parameters[0].equals(XMultiServiceFactory.class)
- && parameters[1].equals(__objectArray)) {
+ && parameters[1].equals(Object[].class)) {
 _nCode = 6;
 _constructor = constructors[i];
 }
@@ -139,7 +128,7 @@ public class FactoryHelper {
 _constructor = constructors[i];
 }
 else if(parameters.length == 1
- && parameters[0].equals(__objectArray)) {
+ && parameters[0].equals(Object[].class)) {
 _nCode = 8;
 _constructor = constructors[i];
 }
diff --git a/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java 
b/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java
index 773ea0a..8f454c7 100644
--- a/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java
+++ b/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java
@@ -220,12 +220,10 @@ public class _XExtendedIndexEntrySupplier extends 
MultiMethodTest {
  */
 public static class UnicodeStringPair {
 final static int valCount = 78;
-static String[] sStringEquivalence = null;
-static char[] iUnicodeEquivalence = null;
+static final String[] sStringEquivalence = new String[valCount];
+static final char[] iUnicodeEquivalence = new char[valCount];
 
 static {
-sStringEquivalence = new String[valCount];
-iUnicodeEquivalence = new char[valCount];
 fillValues();
 }
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: jurt/com

2014-07-27 Thread rbuj
 jurt/com/sun/star/comp/servicemanager/ServiceManager.java  |   34 
+-
 jurt/com/sun/star/lib/connections/pipe/PipeConnection.java |   14 
 jurt/com/sun/star/lib/connections/socket/SocketConnection.java |   13 ---
 3 files changed, 23 insertions(+), 38 deletions(-)

New commits:
commit dfb1d56b71b3e5891635d887043a415b8b0295d6
Author: rbuj 
Date:   Sat Jul 26 12:16:50 2014 +0200

jurt: Enhanced For-Loops

Change-Id: I74a9b8afd1e4a1364c61c7b85277909f38611f6d
Reviewed-on: https://gerrit.libreoffice.org/10553
Reviewed-by: David Tardon 
Tested-by: David Tardon 

diff --git a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java 
b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
index 8def4ac..4a4a4e6 100644
--- a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
+++ b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
@@ -296,10 +296,7 @@ public class ServiceManager implements 
XMultiServiceFactory,
 throws com.sun.star.uno.RuntimeException
 {
 if (eventListener != null) {
-java.util.Iterator enumer = 
eventListener.iterator();
-
-while (enumer.hasNext()) {
-XEventListener listener = enumer.next();
+for (XEventListener listener : eventListener) {
 listener.disposing(new com.sun.star.lang.EventObject(this));
 }
 eventListener.clear();
@@ -468,16 +465,17 @@ public class ServiceManager implements 
XMultiServiceFactory,
 
 String[] serviceNames = xServiceInfo.getSupportedServiceNames();
 
-for ( int i=0; i vec = 
factoriesByServiceNames.get(serviceNames[i]);
-
-if ( !vec.remove(object) )
+for (String serviceName : serviceNames) {
+if (factoriesByServiceNames.containsKey(serviceName)) {
+ArrayList vec = 
factoriesByServiceNames.get(serviceName);
+if (!vec.remove(object)) {
 System.err.println("The implementation " + 
xServiceInfo.getImplementationName() +
-" is not registered for the service " + 
serviceNames[i] + " - ignoring!");
-
-if ( vec.isEmpty() ) // remove the vector if no 
implementations aviable for the service
-factoriesByServiceNames.remove( serviceNames[i] );
+" is not registered for the service " + 
serviceName + " - ignoring!");
+}
+// remove the vector if no implementations aviable for the 
service
+if (vec.isEmpty()) {
+factoriesByServiceNames.remove(serviceName);
+}
 }
 }
 }
@@ -565,12 +563,14 @@ public class ServiceManager implements 
XMultiServiceFactory,
 public boolean supportsService( String serviceName )
 throws com.sun.star.uno.RuntimeException
 {
-for (int i=0; i elements = _aListeners.iterator();
-while(elements.hasNext()) {
-XStreamListener xStreamListener = elements.next();
+for (XStreamListener xStreamListener : _aListeners) {
 xStreamListener.started();
 }
 }
 
 private void notifyListeners_close() {
-Iterator elements = _aListeners.iterator();
-while(elements.hasNext()) {
-XStreamListener xStreamListener = elements.next();
+for (XStreamListener xStreamListener : _aListeners) {
 xStreamListener.closed();
 }
 }
 
 private void notifyListeners_error(com.sun.star.uno.Exception exception) {
-Iterator elements = _aListeners.iterator();
-while(elements.hasNext()) {
-XStreamListener xStreamListener = elements.next();
+for (XStreamListener xStreamListener : _aListeners) {
 xStreamListener.error(exception);
 }
 }
@@ -215,4 +208,3 @@ public class PipeConnection implements XConnection, 
XConnectionBroadcaster {
 }
 
 }
-
diff --git a/jurt/com/sun/star/lib/connections/socket/SocketConnection.java 
b/jurt/com/sun/star/lib/connections/socket/SocketConnection.java
index e849d8b..f7ad911 100644
--- a/jurt/com/sun/star/lib/connections/socket/SocketConnection.java
+++ b/jurt/com/sun/star/lib/connections/socket/SocketConnection.java
@@ -25,7 +25,6 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.net.Socket;
 import java.util.ArrayList;
-import java.util.Iterator;
 
 import com.sun.star.connection.XConnection;
 import com.sun.star.connection.XConnectionBroadcaster;
@@ -89,25 +88,19 @@ public class SocketConnection implements XConnection, 
XConnectionBroadcaster {
 }
 
 private void notifyListeners_open() {
-Iterator elements = _listeners.iterator();
-while(elements.hasNext()) {
-XStreamListener xStreamListener = elements.next();
+for (XStreamListener xStreamListener : _listeners) {
 xStreamListener.started();
 }
 }
 
 private 

[Libreoffice-commits] core.git: jurt/com jurt/test

2014-02-26 Thread Alexander Wilms
 jurt/com/sun/star/comp/loader/FactoryHelper.java  |4 +--
 jurt/test/com/sun/star/uno/AnyConverter_Test.java |   24 +++---
 2 files changed, 14 insertions(+), 14 deletions(-)

New commits:
commit e524ecb3c9eedee99a1acd33c785592e9ae3bd54
Author: Alexander Wilms 
Date:   Tue Feb 25 19:10:01 2014 +0100

Remove visual noise from jurt

Change-Id: I9f2d9d0ee99623495440fd66961b56a73bd4124a
Reviewed-on: https://gerrit.libreoffice.org/8276
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/jurt/com/sun/star/comp/loader/FactoryHelper.java 
b/jurt/com/sun/star/comp/loader/FactoryHelper.java
index e035082..ea7536a 100644
--- a/jurt/com/sun/star/comp/loader/FactoryHelper.java
+++ b/jurt/com/sun/star/comp/loader/FactoryHelper.java
@@ -170,7 +170,7 @@ public class FactoryHelper {
 }
 
 // XComponentContext impl
-
//__
+
 public Object createInstanceWithContext(
 XComponentContext xContext )
 throws com.sun.star.uno.Exception
@@ -236,7 +236,7 @@ public class FactoryHelper {
 throw new com.sun.star.uno.Exception( 
instantiationException.toString() );
 }
 }
-
//__
+
 public Object createInstanceWithArgumentsAndContext(
 Object rArguments[], XComponentContext xContext )
 throws com.sun.star.uno.Exception
diff --git a/jurt/test/com/sun/star/uno/AnyConverter_Test.java 
b/jurt/test/com/sun/star/uno/AnyConverter_Test.java
index daf129e..26492f1 100644
--- a/jurt/test/com/sun/star/uno/AnyConverter_Test.java
+++ b/jurt/test/com/sun/star/uno/AnyConverter_Test.java
@@ -23,18 +23,18 @@ import org.junit.Test;
 import static org.junit.Assert.*;
 
 public final class AnyConverter_Test {
-Any anyBool; //
-Any anyChar; //
-Any anyByte; //
-Any anyShort; //
-Any anyInt; //
-Any anyLong; //
-Any anyFloat; //
-Any anyDouble; //
-Any anyStr; //
-Any anyType; //
-Any anyArByte; //
-Any anyVoid;   //
+Any anyBool;
+Any anyChar;
+Any anyByte;
+Any anyShort;
+Any anyInt;
+Any anyLong;
+Any anyFloat;
+Any anyDouble;
+Any anyStr;
+Any anyType;
+Any anyArByte;
+Any anyVoid;
 Any anyXTypeProvider;
 
 Boolean aBool= new Boolean(true);
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits
diff --git a/jurt/com/sun/star/lib/uno/environments/remote/Message.java 
b/jurt/com/sun/star/lib/uno/environments/remote/Message.java
index 4a6921b..b34295a 100644
--- a/jurt/com/sun/star/lib/uno/environments/remote/Message.java
+++ b/jurt/com/sun/star/lib/uno/environments/remote/Message.java
@@ -19,8 +19,8 @@
 
 package com.sun.star.lib.uno.environments.remote;
 
-import com.sun.star.uno.IMethodDescription;
-import com.sun.star.uno.ITypeDescription;
+import com.sun.star.lib.uno.typedesc.MethodDescription;
+import com.sun.star.lib.uno.typedesc.TypeDescription;
 import com.sun.star.uno.XCurrentContext;
 
 /**
@@ -29,7 +29,7 @@ import com.sun.star.uno.XCurrentContext;
 public class Message {
 public Message(
 ThreadId threadId, boolean request, String objectId,
-ITypeDescription type, IMethodDescription method, boolean synchronous,
+TypeDescription type, MethodDescription method, boolean synchronous,
 XCurrentContext currentContext, boolean abnormalTermination,
 Object result, Object[] arguments)
 {
@@ -87,7 +87,7 @@ public class Message {
  * @return the (non-null) type for a request, 
null
  * for a reply.
  */
-public final ITypeDescription getType() {
+public final TypeDescription getType() {
 return type;
 }
 
@@ -95,13 +95,13 @@ public class Message {
  * Returns the method description of a request message.
  *
  * Valid only for request messages.  The returned
  * IMethodDescription is consistent with the type of the
  * message.
  *
  * @return the (non-null) method description for a request,
  * null for a reply.
  */
-public final IMethodDescription getMethod() {
+public final MethodDescription getMethod() {
 return method;
 }
 
@@ -177,8 +177,8 @@ public class Message {
 private final ThreadId threa
@@ -95,13 +95,13 @@ public class Message {
  *
  * Valid only for request messages.  The returned
- * IMethodDescription is consistent with the type of the
+ * MethodDescription is consistent with the type of the
  * message.
  *

[Libreoffice-commits] core.git: jurt/com

2016-06-06 Thread Noel Grandin
 jurt/com/sun/star/lib/uno/environments/remote/JobQueue.java |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 02858c3d4900fba4d7fa596b221eb426b35ca3e9
Author: Noel Grandin 
Date:   Mon Jun 6 12:57:43 2016 +0200

fix synchronization of JobQueue

Change-Id: I51d58896065a06564d7963aab1145ba9083fdefc
